pytest-kivy
===========

Provides pytest fixtures to more easily test Kivy GUI apps.

For more information: https://matham.github.io/pytest-kivy/index.html


.. image:: https://coveralls.io/repos/github/matham/pytest-kivy/badge.svg?branch=master
    :target: https://coveralls.io/github/matham/pytest-kivy?branch=master
    :alt: Coverage status


.. image:: https://github.com/matham/pytest-kivy/workflows/Python%20application/badge.svg
    :target: https://github.com/matham/pytest-kivy/actions
    :alt: Github action status
